| Title: | GEOexplorer: a webserver for gene expression analysis and visualisation |
|---|---|
| Description: | GEOexplorer is a webserver and R/Bioconductor package and web application that enables users to perform gene expression analysis. The development of GEOexplorer was made possible because of the excellent code provided by GEO2R (https: //www.ncbi.nlm.nih.gov/geo/geo2r/). |
| Authors: | Guy Hunt [aut, cre] (ORCID: <https://orcid.org/0000-0002-5217-2678>), Rafael Henkin [ctb, ths] (ORCID: <https://orcid.org/0000-0002-5511-5230>), Alfredo Iacoangeli [ctb, ths] (ORCID: <https://orcid.org/0000-0002-5280-5017>), Fabrizio Smeraldi [ctb, ths] (ORCID: <https://orcid.org/0000-0002-0057-8940>), Michael Barnes [ctb, ths] (ORCID: <https://orcid.org/0000-0001-9097-7381>) |
| Maintainer: | Guy Hunt <[email protected]> |
| License: | GPL-3 |
| Version: | 1.18.0 |
| Built: | 2026-05-31 06:40:43 UTC |
| Source: | https://github.com/bioc/GEOexplorer |
This function loads the GEOexplorer Shiny App. The GEOexplorer Shiny App extends GEO2R's functionalities by enabling a richer set of analysis and graphics to be performed/generated from the gene expression data.
loadApp()loadApp()
Large Shiny App
Guy Hunt
app <- loadApp()app <- loadApp()